@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 /*
  * This file is part of the JsonSchema package.
  *
@@ -9,6 +11,7 @@
 
 namespace JsonSchema\Constraints;
 
+use JsonSchema\ConstraintError;
 use JsonSchema\Entity\JsonPointer;
 use JsonSchema\Exception\InvalidArgumentException;
 use JsonSchema\Exception\ValidationException;
@@ -23,10 +26,11 @@ class BaseConstraint
     /**
      * @var array Errors
      */
-    protected $errors = array();
+    protected $errors = [];
 
     /**
      * @var int All error types which have occurred
+     * @phpstan-var int-mask-of<Validator::ERROR_*>
      */
     protected $errorMask = Validator::ERROR_NONE;
 
@@ -35,37 +39,41 @@ class BaseConstraint
      */
     protected $factory;
 
-    /**
-     * @param Factory $factory
-     */
     public function __construct(?Factory $factory = null)
     {
         $this->factory = $factory ?: new Factory();
     }
 
-    public function addError(?JsonPointer $path, $message, $constraint = '', ?array $more = null)
+    public function addError(ConstraintError $constraint, ?JsonPointer $path = null, array $more = []): void
     {
-        $error = array(
+        $message = $constraint->getMessage();
+        $name = $constraint->getValue();
+        $error = [
             'property' => $this->convertJsonPointerIntoPropertyPath($path ?: new JsonPointer('')),
             'pointer' => ltrim(strval($path ?: new JsonPointer('')), '#'),
-            'message' => $message,
-            'constraint' => $constraint,
+            'message' => ucfirst(vsprintf($message, array_map(function ($val) {
+                if (is_scalar($val)) {
+                    return is_bool($val) ? var_export($val, true) : $val;
+                }
+
+                return json_encode($val);
+            }, array_values($more)))),
+            'constraint' => [
+                'name' => $name,
+                'params' => $more
+            ],
             'context' => $this->factory->getErrorContext(),
-        );
+        ];
 
         if ($this->factory->getConfig(Constraint::CHECK_MODE_EXCEPTIONS)) {
             throw new ValidationException(sprintf('Error validating %s: %s', $error['pointer'], $error['message']));
         }
 
-        if (is_array($more) && count($more) > 0) {
-            $error += $more;
-        }
-
         $this->errors[] = $error;
         $this->errorMask |= $error['context'];
     }
 
-    public function addErrors(array $errors)
+    public function addErrors(array $errors): void
     {
         if ($errors) {
             $this->errors = array_merge($this->errors, $errors);
@@ -78,7 +86,10 @@ class BaseConstraint
         }
     }
 
-    public function getErrors($errorContext = Validator::ERROR_ALL)
+    /**
+     * @phpstan-param int-mask-of<Validator::ERROR_*> $errorContext
+     */
+    public function getErrors(int $errorContext = Validator::ERROR_ALL): array
     {
         if ($errorContext === Validator::ERROR_ALL) {
             return $this->errors;
@@ -91,7 +102,10 @@ class BaseConstraint
         });
     }
 
-    public function numErrors($errorContext = Validator::ERROR_ALL)
+    /**
+     * @phpstan-param int-mask-of<Validator::ERROR_*> $errorContext
+     */
+    public function numErrors(int $errorContext = Validator::ERROR_ALL): int
     {
         if ($errorContext === Validator::ERROR_ALL) {
             return count($this->errors);
@@ -100,7 +114,7 @@ class BaseConstraint
         return count($this->getErrors($errorContext));
     }
 
-    public function isValid()
+    public function isValid(): bool
     {
         return !$this->getErrors();
     }
@@ -109,30 +123,26 @@ class BaseConstraint
      * Clears any reported errors.  Should be used between
      * multiple validation checks.
      */
-    public function reset()
+    public function reset(): void
     {
-        $this->errors = array();
+        $this->errors = [];
         $this->errorMask = Validator::ERROR_NONE;
     }
 
     /**
      * Get the error mask
      *
-     * @return int
+     * @phpstan-return int-mask-of<Validator::ERROR_*>
      */
-    public function getErrorMask()
+    public function getErrorMask(): int
     {
         return $this->errorMask;
     }
 
     /**
      * Recursively cast an associative array to an object
-     *
-     * @param array $array
-     *
-     * @return object
      */
-    public static function arrayToObjectRecursive($array)
+    public static function arrayToObjectRecursive(array $array): object
     {
         $json = json_encode($array);
         if (json_last_error() !== \JSON_ERROR_NONE) {
@@ -145,4 +155,27 @@ class BaseConstraint
 
         return (object) json_decode($json);
     }
+
+    /**
+     * Transform a JSON pattern into a PCRE regex
+     */
+    public static function jsonPatternToPhpRegex(string $pattern): string
+    {
+        return '~' . str_replace('~', '\\~', $pattern) . '~u';
+    }
+
+    /**
+     * @return string property path
+     */
+    protected function convertJsonPointerIntoPropertyPath(JsonPointer $pointer): string
+    {
+        $result = array_map(
+            function ($path) {
+                return sprintf(is_numeric($path) ? '[%d]' : '.%s', $path);
+            },
+            $pointer->getPropertyPaths()
+        );
+
+        return trim(implode('', $result), '.');
+    }
 }
