@@ -13,10 +13,10 @@ class RequireTest extends BaseTestCase
 {
     protected $validateSchema = true;
 
-    public function getInvalidTests()
+    public function getInvalidTests(): array
     {
-        return array(
-            array(
+        return [
+            [
                 '{
                   "state":"DF"
                 }',
@@ -27,14 +27,14 @@ class RequireTest extends BaseTestCase
                     "city":{"type":"string"}
                   }
                 }'
-            )
-        );
+            ]
+        ];
     }
 
-    public function getValidTests()
+    public function getValidTests(): array
     {
-        return array(
-            array(
+        return [
+            [
                 '{
                   "state":"DF",
                   "city":"Brasília"
@@ -46,7 +46,7 @@ class RequireTest extends BaseTestCase
                     "city":{"type":"string"}
                   }
                 }'
-            )
-        );
+            ]
+        ];
     }
 }
