@@ -24,39 +24,37 @@ class TypeTest extends TestCase
 {
     /**
      * @see testIndefiniteArticleForTypeInTypeCheckErrorMessage
-     *
-     * @return array
      */
-    public function provideIndefiniteArticlesForTypes()
+    public function provideIndefiniteArticlesForTypes(): array
     {
-        return array(
-            array('integer', 'an integer'),
-            array('number', 'a number'),
-            array('boolean', 'a boolean'),
-            array('object', 'an object'),
-            array('array', 'an array'),
-            array('string', 'a string'),
-            array('null', 'a null', array(), 'array'),
-            array(array('string', 'boolean', 'integer'), 'a string, a boolean or an integer'),
-            array(array('string', 'boolean'), 'a string or a boolean'),
-            array(array('string'), 'a string'),
-        );
+        return [
+            ['integer', 'an integer'],
+            ['number', 'a number'],
+            ['boolean', 'a boolean'],
+            ['object', 'an object'],
+            ['array', 'an array'],
+            ['string', 'a string'],
+            ['null', 'a null', [], 'array'],
+            [['string', 'boolean', 'integer'], 'a string, a boolean or an integer'],
+            [['string', 'boolean'], 'a string or a boolean'],
+            [['string'], 'a string'],
+        ];
     }
 
     /**
      * @dataProvider provideIndefiniteArticlesForTypes
      */
-    public function testIndefiniteArticleForTypeInTypeCheckErrorMessage($type, $wording, $value = null, $label = 'NULL')
+    public function testIndefiniteArticleForTypeInTypeCheckErrorMessage($type, $wording, $value = null, $label = 'NULL'): void
     {
         $constraint = new TypeConstraint();
-        $constraint->check($value, (object) array('type' => $type));
+        $constraint->check($value, (object) ['type' => $type]);
         $this->assertTypeConstraintError(ucwords($label) . " value found, but $wording is required", $constraint);
     }
 
     /**
      * Test uncovered areas of the loose type checker
      */
-    public function testLooseTypeChecking()
+    public function testLooseTypeChecking(): void
     {
         $v = new \stdClass();
         $v->property = 'dataOne';
@@ -68,11 +66,8 @@ class TypeTest extends TestCase
 
     /**
      * Helper to assert an error message
-     *
-     * @param string         $expected
-     * @param TypeConstraint $actual
      */
-    private function assertTypeConstraintError($expected, TypeConstraint $actual)
+    private function assertTypeConstraintError(string $expected, TypeConstraint $actual): void
     {
         $actualErrors = $actual->getErrors();
 
@@ -80,7 +75,7 @@ class TypeTest extends TestCase
 
         $actualError = $actualErrors[0];
 
-        $this->assertInternalType('array', $actualError, sprintf('Failed to assert that Type error is an array, %s given', gettype($actualError)));
+        $this->assertIsArray($actualError, sprintf('Failed to assert that Type error is an array, %s given', gettype($actualError)));
 
         $messageKey = 'message';
         $this->assertArrayHasKey(
@@ -94,12 +89,12 @@ class TypeTest extends TestCase
         $this->assertSame($expected, $actualMessage); // the same for the strictness
     }
 
-    public function validNameWordingDataProvider()
+    public function validNameWordingDataProvider(): array
     {
-        $wordings = array();
+        $wordings = [];
 
         foreach (array_keys(TypeConstraint::$wording) as $value) {
-            $wordings[] = array($value);
+            $wordings[] = [$value];
         }
 
         return $wordings;
@@ -108,7 +103,7 @@ class TypeTest extends TestCase
     /**
      * @dataProvider validNameWordingDataProvider
      */
-    public function testValidateTypeNameWording($nameWording)
+    public function testValidateTypeNameWording($nameWording): void
     {
         $t = new TypeConstraint();
         $r = new \ReflectionObject($t);
@@ -116,32 +111,31 @@ class TypeTest extends TestCase
         $m->setAccessible(true);
 
         $m->invoke($t, $nameWording);
+        $this->expectNotToPerformAssertions();
     }
 
-    public function testInvalidateTypeNameWording()
+    public function testInvalidateTypeNameWording(): void
     {
         $t = new TypeConstraint();
         $r = new \ReflectionObject($t);
         $m = $r->getMethod('validateTypeNameWording');
         $m->setAccessible(true);
 
-        $this->setExpectedException(
-            '\UnexpectedValueException',
-            "No wording for 'notAValidTypeName' available, expected wordings are: [an integer, a number, a boolean, an object, an array, a string, a null]"
-        );
+        $this->expectException('\UnexpectedValueException');
+        $this->expectExceptionMessage("No wording for 'notAValidTypeName' available, expected wordings are: [an integer, a number, a boolean, an object, an array, a string, a null]");
+
         $m->invoke($t, 'notAValidTypeName');
     }
 
-    public function testValidateTypeException()
+    public function testValidateTypeException(): void
     {
         $t = new TypeConstraint();
         $data = new \stdClass();
         $schema = json_decode('{"type": "notAValidTypeName"}');
 
-        $this->setExpectedException(
-            'JsonSchema\Exception\InvalidArgumentException',
-            'object is an invalid type for notAValidTypeName'
-        );
+        $this->expectException('JsonSchema\Exception\InvalidArgumentException');
+        $this->expectExceptionMessage('object is an invalid type for notAValidTypeName');
+
         $t->check($data, $schema);
     }
 }
