@@ -13,10 +13,10 @@ class UnionTypesTest extends BaseTestCase
 {
     protected $validateSchema = true;
 
-    public function getInvalidTests()
+    public function getInvalidTests(): array
     {
-        return array(
-            array(
+        return [
+            [
                 '{
                   "stringOrNumber":4.8,
                   "booleanOrNull":5
@@ -28,14 +28,14 @@ class UnionTypesTest extends BaseTestCase
                     "booleanOrNull":{"type":["boolean","null"]}
                   }
                 }'
-            )
-        );
+            ]
+        ];
     }
 
-    public function getValidTests()
+    public function getValidTests(): array
     {
-        return array(
-            array(
+        return [
+            [
                 '{
                   "stringOrNumber":4.8,
                   "booleanOrNull":false
@@ -47,7 +47,7 @@ class UnionTypesTest extends BaseTestCase
                     "booleanOrNull":{"type":["boolean","null"]}
                   }
                 }'
-            )
-        );
+            ]
+        ];
     }
 }
