@@ -20,15 +20,15 @@ class Draft3Test extends BaseDraftTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getFilePaths()
+    protected function getFilePaths(): array
     {
-        return array(
+        return [
             realpath(__DIR__ . $this->relativeTestsRoot . '/draft3'),
             realpath(__DIR__ . $this->relativeTestsRoot . '/draft3/optional')
-        );
+        ];
     }
 
-    public function getInvalidForAssocTests()
+    public function getInvalidForAssocTests(): array
     {
         $tests = parent::getInvalidForAssocTests();
         unset(
@@ -39,7 +39,7 @@ class Draft3Test extends BaseDraftTestCase
         return $tests;
     }
 
-    public function getValidForAssocTests()
+    public function getValidForAssocTests(): array
     {
         $tests = parent::getValidForAssocTests();
         unset(
@@ -53,14 +53,14 @@ class Draft3Test extends BaseDraftTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getSkippedTests()
+    protected function getSkippedTests(): array
     {
-        return array(
+        return [
             // Optional
             'bignum.json',
             'format.json',
             'jsregex.json',
             'zeroTerminatedFloats.json'
-        );
+        ];
     }
 }
